# UseDynLib YEAB, .registration = TRUE
# Generated by roxygen2: do not edit by hand

export(KL_div)
export(ab_range_normalization)
export(balci2019)
export(berm)
export(biexponential)
export(bp_opt)
export(ceiling_multiple)
export(curv_index_fry)
export(curv_index_int)
export(entropy_kde2d)
export(eq_hyp)
export(event_extractor)
export(exhaustive_lhl)
export(exhaustive_sbp)
export(exp_fit)
export(f_table)
export(fleshler_hoffman)
export(fwhm)
export(gaussian_fit)
export(gell_like)
export(get_bins)
export(hyperbolic_fit)
export(ind_trials_opt)
export(mut_info_discrete)
export(mut_info_knn)
export(n_between_intervals)
export(objective_bp)
export(optimize_berm)
export(read_med)
export(sample_from_density)
export(trapezoid_auc)
export(unit_normalization)
export(val_in_interval)
importFrom(foreach,"%dopar%")
importFrom(foreach,foreach)
importFrom(KernSmooth,bkde)
importFrom(doParallel,registerDoParallel)
importFrom(MASS,kde2d,"width.SJ")
importFrom(Polychrome,createPalette)
importFrom(cluster, clusGap, maxSE)
importFrom(dplyr,between)
importFrom(dplyr,lag)
importFrom("data.table",last)
importFrom(infotheo,discretize)
importFrom(infotheo,mutinformation)
importFrom(magrittr,"%>%")
importFrom(minpack.lm,nls.lm)
importFrom(scales,show_col,alpha)
importFrom(sfsmisc,integrate.xy)
importFrom(boot,boot)
importFrom(zoo,rollapply)
importFrom(usethis, use_data)
importFrom(ggplot2, ggplot, aes, geom_point)
importFrom(grid, unit,textGrob)
importFrom(gridExtra, grid.arrange)
importFrom(stats, median, optim, coef, fitted, approx, integrate, quantile)
importFrom("grDevices", "col2rgb", "grey", "rgb")
importFrom("graphics", "abline", "arrows", "axis", "box", "boxplot",
             "grid", "hist", "layout", "lines", "mtext", "par",
             "polygon", "stripchart", "text")
importFrom("stats", "approx", "bw.SJ", "coef", "cor", "density",
             "fitted", "integrate", "lm", "loess", "median", "na.omit",
             "nls", "nls.control", "optim", "pnorm", "quantile",
             "rbinom", "runif")
    importFrom("stats", "dexp", "setNames")
importFrom("utils", "read.table", "stack", "tail", "write.csv")
importFrom(grid, unit, gpar, grid.polygon, grid.text, grid.layout, grid.newpage, pushViewport, viewport, grid.rect, grid.points, grid.xaxis, grid.yaxis, grid.segments)
importFrom(minpack.lm, "nls.lm.control")
importFrom(utils, "stack", "write.csv")
importFrom(ggplot2, theme_gray, element_line, element_blank, element_text, element_rect, theme, margin, theme_grey)
importFrom(cluster, pam)
importFrom(dplyr, group_by, summarise)
importFrom(FNN, mutinfo)
