
Shield: [![CC BY 4.0][cc-by-shield]][cc-by]

This work is licensed under a
[Creative Commons Attribution 4.0 International License][cc-by].

[![CC BY 4.0][cc-by-image]][cc-by]

[cc-by]: http://creativecommons.org/licenses/by/4.0/
[cc-by-image]: https://i.creativecommons.org/l/by/4.0/88x31.png
[cc-by-shield]: https://img.shields.io/badge/License-CC%20BY%204.0-lightgrey.svg

# YEAB
Yeab Ease the Analysis of Behavior (YEAB) is an R package that implements

1. Several metrics from information theory as the Kullback-Leibler divergence and Mutual information, for discrete as well as continuous variables.
2. Custom routines of Experimental Analysis of Behavior. For example, functions to process data from MED operant boxes.
3. Several common analysis, like fitting hyperbolic and exponential models to delay discounting tasks, fitting the biexponential model to IRTs from variable interval schedules, etc.

---

# Nota

Este paquete se desarrolló con presupuesto de la **Convocatoria de Ciencia Básica y/o Ciencia de Frontera, Modalidad: Paradigmas y Controversias de la Ciencia 2022**, con número de proyecto 320943 “APRENDIZAJE EN UNA TAREA DE ESTIMACIÓN TEMPORAL: EL PAPEL DE LA MAXIMIZACIÓN DE LA INFORMACI

---

For more information about how to install and use YEAB check our [Wiki](https://github.com/jealcalat/YEAB/wiki)!

