## ----echo = FALSE, message = FALSE, warning = FALSE---------------------------
library(YEAB)

## ----tidy = FALSE, message = FALSE, warning = FALSE---------------------------
data("fi60_raw_from_med")
temp_file <- tempfile(fileext = ".txt")
writeLines(fi60_raw_from_med, temp_file)
path_to_save <- getwd()

## ----tidy = FALSE-------------------------------------------------------------
example_processed <- read_med(
  fname = temp_file, save_file = FALSE,
  path_save = path_to_save, col_r = "C:", out = TRUE,
  col_names = c("time", "event"), num_col = 6, time_dot_event = TRUE
)

## ----tidy = FALSE-------------------------------------------------------------
head(example_processed, 10)

